class User < ActiveRecord::Base
  has_many :solutions
  has_many :tasks, :through => :solutions
  attr_accessor :password

  validates_presence_of :neptun
  validates_uniqueness_of :neptun, :limit => 6, :case_sensitive=>false
  validates_length_of :password, :within=>4..40, :if => :password_required?
  validates_confirmation_of :password, :if => :password_required?

  before_save :encrypt_password
  
  def encrypt_password
    return if password.blank?
    if new_record?
      self.salt = ActiveSupport::SecureRandom.base64(8)
    end
    self.encrypted_password = User.encrypt(password, salt)
  end
  
  def self.encrypt(pass,salt)
    #Digest::SHA2.hexdigest(self.salt + pass)
    Digest::SHA1.hexdigest("--#{salt}--#{pass}--")
  end

  def password_required?
    encrypted_password.blank? || !password.blank?
  end
  
  def self.authenticate(neptun,pass)
    user = find_by_neptun(neptun)
    user && user.authenticated?(pass) ? user : nil
  end
  
  def authenticated?(pass)
    encrypted_password == User.encrypt(pass,salt)
  end
end
